@@ -31,7 +31,7 @@ final class GetQueueUrlRequest extends Input
     /**
      * @param array{
      *   QueueName?: string,
-     *   QueueOwnerAWSAccountId?: string,
+     *   QueueOwnerAWSAccountId?: null|string,
      *   '@region'?: string|null,
      * } $input
      */
@@ -45,7 +45,7 @@ final class GetQueueUrlRequest extends Input
     /**
      * @param array{
      *   QueueName?: string,
-     *   QueueOwnerAWSAccountId?: string,
+     *   QueueOwnerAWSAccountId?: null|string,
      *   '@region'?: string|null,
      * }|GetQueueUrlRequest $input
      */
@@ -70,7 +70,10 @@ final class GetQueueUrlRequest extends Input
     public function request(): Request
     {
         // Prepare headers
-        $headers = ['content-type' => 'application/x-www-form-urlencoded'];
+        $headers = [
+            'Content-Type' => 'application/x-amz-json-1.0',
+            'X-Amz-Target' => 'AmazonSQS.GetQueueUrl',
+        ];
 
         // Prepare query
         $query = [];
@@ -79,7 +82,8 @@ final class GetQueueUrlRequest extends Input
         $uriString = '/';
 
         // Prepare Body
-        $body = http_build_query(['Action' => 'GetQueueUrl', 'Version' => '2012-11-05'] + $this->requestBody(), '', '&', \PHP_QUERY_RFC1738);
+        $bodyPayload = $this->requestBody();
+        $body = empty($bodyPayload) ? '{}' : json_encode($bodyPayload, 4194304);
 
         // Return the Request
         return new Request('POST', $uriString, $query, $headers, StreamFactory::create($body));
