@@ -22,15 +22,19 @@ class ChangeMessageVisibilityBatchRequestTest extends TestCase
         /** @see https://docs.aws.amazon.com/AWSSimpleQueueService/latest/APIReference/API_ChangeMessageVisibilityBatch.html */
         $expected = '
             POST / HTTP/1.0
-            Content-Type: application/x-www-form-urlencoded
+            Content-Type: application/x-amz-json-1.0
+            x-amz-target: AmazonSQS.ChangeMessageVisibilityBatch
 
-            Action=ChangeMessageVisibilityBatch
-            &ChangeMessageVisibilityBatchRequestEntry.1.Id=qwertyuiop
-            &ChangeMessageVisibilityBatchRequestEntry.1.ReceiptHandle=MbZj6wDWli%2BJvwwJaBV%2B3dcjk2YW2vA3%2BSTFFljT
-            &ChangeMessageVisibilityBatchRequestEntry.1.VisibilityTimeout=60
-            &QueueUrl=queueUrl
-            &Version=2012-11-05
-                ';
+            {
+                "QueueUrl": "queueUrl",
+                "Entries": [
+                    {
+                        "Id": "qwertyuiop",
+                        "ReceiptHandle": "MbZj6wDWli+JvwwJaBV+3dcjk2YW2vA3+STFFljT",
+                        "VisibilityTimeout": 60
+                    }
+                ]
+            }';
 
         self::assertRequestEqualsHttpRequest($expected, $input->request());
     }
