@@ -21,14 +21,18 @@ class DeleteMessageBatchRequestTest extends TestCase
         /** @see https://docs.aws.amazon.com/AWSSimpleQueueService/latest/APIReference/API_DeleteMessageBatch.html */
         $expected = '
             POST / HTTP/1.0
-            Content-Type: application/x-www-form-urlencoded
+            Content-Type: application/x-amz-json-1.0
+            x-amz-target: AmazonSQS.DeleteMessageBatch
 
-            Action=DeleteMessageBatch
-            &DeleteMessageBatchRequestEntry.1.Id=qwertyuiop
-            &DeleteMessageBatchRequestEntry.1.ReceiptHandle=MbZj6wDWli%2BJvwwJaBV%2B3dcjk2YW2vA3%2BSTFFljT
-            &QueueUrl=queueUrl
-            &Version=2012-11-05
-                ';
+            {
+                "QueueUrl": "queueUrl",
+                "Entries": [
+                    {
+                        "Id": "qwertyuiop",
+                        "ReceiptHandle": "MbZj6wDWli+JvwwJaBV+3dcjk2YW2vA3+STFFljT"
+                    }
+                ]
+            }';
 
         self::assertRequestEqualsHttpRequest($expected, $input->request());
     }
