@@ -17,13 +17,13 @@ class DeleteMessageRequestTest extends TestCase
         /** @see https://docs.aws.amazon.com/AWSSimpleQueueService/latest/APIReference/API_DeleteMessage.html */
         $expected = '
             POST / HTTP/1.0
-            Content-Type: application/x-www-form-urlencoded
+            Content-Type: application/x-amz-json-1.0
+            x-amz-target: AmazonSQS.DeleteMessage
 
-            Action=DeleteMessage
-            &Version=2012-11-05
-            &QueueUrl=queueUrl
-            &ReceiptHandle=MbZj6wDWli%2BJvwwJaBV%2B3dcjk2YW2vA3%2BSTFFljT
-        ';
+            {
+                "QueueUrl": "queueUrl",
+                "ReceiptHandle": "MbZj6wDWli+JvwwJaBV+3dcjk2YW2vA3+STFFljT"
+            }';
 
         self::assertRequestEqualsHttpRequest($expected, $input->request());
     }
