@@ -17,15 +17,13 @@ class GetQueueAttributesRequestTest extends TestCase
         /** @see https://docs.aws.amazon.com/AWSSimpleQueueService/latest/APIReference/API_GetQueueAttributes.html */
         $expected = '
             POST / HTTP/1.0
-            Content-Type: application/x-www-form-urlencoded
+            Content-Type: application/x-amz-json-1.0
+            x-amz-target: AmazonSQS.GetQueueAttributes
 
-            Action=GetQueueAttributes
-            &Version=2012-11-05
-            &QueueUrl=queueUrl
-            &AttributeName.1=VisibilityTimeout
-            &AttributeName.2=DelaySeconds
-            &AttributeName.3=ReceiveMessageWaitTimeSeconds
-        ';
+            {
+                "QueueUrl": "queueUrl",
+                "AttributeNames": ["VisibilityTimeout", "DelaySeconds", "ReceiveMessageWaitTimeSeconds"]
+            }';
 
         self::assertRequestEqualsHttpRequest($expected, $input->request());
     }
