@@ -16,12 +16,12 @@ class PurgeQueueRequestTest extends TestCase
         /** @see https://docs.aws.amazon.com/AWSSimpleQueueService/latest/APIReference/API_PurgeQueue.html */
         $expected = '
             POST / HTTP/1.0
-            Content-Type: application/x-www-form-urlencoded
+            Content-Type: application/x-amz-json-1.0
+            x-amz-target: AmazonSQS.PurgeQueue
 
-            Action=PurgeQueue
-            &Version=2012-11-05
-            &QueueUrl=queueUrl
-        ';
+            {
+                "QueueUrl": "queueUrl"
+            }';
 
         self::assertRequestEqualsHttpRequest($expected, $input->request());
     }
