@@ -23,19 +23,18 @@ class ReceiveMessageRequestTest extends TestCase
         /** @see https://docs.aws.amazon.com/AWSSimpleQueueService/latest/APIReference/API_ReceiveMessage.html */
         $expected = '
             POST / HTTP/1.0
-            Content-Type: application/x-www-form-urlencoded
+            Content-Type: application/x-amz-json-1.0
+            x-amz-target: AmazonSQS.ReceiveMessage
 
-            Action=ReceiveMessage
-            &Version=2012-11-05
-            &QueueUrl=queueUrl
-            &AttributeName.1=MessageGroupId
-            &AttributeName.2=MessageDeduplicationId
-            &MessageAttributeName.1=Attribute1
-            &MaxNumberOfMessages=5
-            &VisibilityTimeout=15
-            &WaitTimeSeconds=20
-            &ReceiveRequestAttemptId=abcdef
-        ';
+            {
+                "QueueUrl": "queueUrl",
+                "AttributeNames": ["MessageGroupId", "MessageDeduplicationId"],
+                "MessageAttributeNames": ["Attribute1"],
+                "MaxNumberOfMessages": 5,
+                "VisibilityTimeout": 15,
+                "WaitTimeSeconds": 20,
+                "ReceiveRequestAttemptId": "abcdef"
+            }';
 
         self::assertRequestEqualsHttpRequest($expected, $input->request());
     }
